'use strict';

/**
 * @param {Egg.Application} app - egg application
 */
module.exports = app => {
  const { router, controller } = app;
  router.get('/', controller.home.index);

  // 科目表设置路由
  router.resources('subject', '/api/train/subject', controller.subject); // index、create、show、destroy
  router.post('subject', '/api/train/subject/update/:id', controller.subject.update);

  // 教师表设置路由
  router.get('teacher', '/api/train/teacher/show/:id', controller.teacher.show);
  router.resources('teacher', '/api/train/teacher', controller.teacher); // index、create、show、destroy
  router.post('teacher', '/api/train/teacher/status', controller.teacher.status);

  // 作业表配置路由
  router.post('task', '/api/train/task', controller.task.create);
  router.delete('task', '/api/train/task/:id', controller.task.delete);
  router.post('task', '/api/train/task/update/:id', controller.task.update);
  router.get('task', '/api/train/task', controller.task.query);
  router.get('task', '/api/train/task/show/:id', controller.task.show);

  // 问卷题库表配置路由
  router.post('question', '/api/train/question', controller.question.create);
  router.delete('question', '/api/train/question/:id', controller.question.delete);
  router.post('question', '/api/train/question/update/:id', controller.question.update);
  router.get('question', '/api/train/question', controller.question.query);
  router.get('question', '/api/train/question/show/:id', controller.question.show);

  // 问卷表配置路由
  router.post('questionnaire', '/api/train/questionnaire', controller.questionnaire.create);
  router.delete('questionnaire', '/api/train/questionnaire/:id', controller.questionnaire.delete);
  router.post('questionnaire', '/api/train/questionnaire/update/:id', controller.questionnaire.update);
  router.get('questionnaire', '/api/train/questionnaire', controller.questionnaire.query);
  router.get('questionnaire', '/api/train/questionnaire/show/:id', controller.questionnaire.show);

  // 学生表设置路由
  router.get('sutdent', '/api/train/student/seek', controller.student.seek);
  router.resources('student', '/api/train/student', controller.student); // index、create、show、destroy
  router.post('student', '/api/train/student/update/:id', controller.student.update);

  // 班主任表设置路由
  router.resources('headteacher', '/api/train/headteacher', controller.headteacher); // index、create、show、destroy
  router.post('headteacher', '/api/train/headteacher/update/:id', controller.headteacher.update);

  // 寝室表设置路由
  router.resources('bedroom', '/api/train/bedroom', controller.bedroom); // index、create、show、destroy
  router.post('bedroom', '/api/train/bedroom/update/:id', controller.bedroom.update);
  router.post('bedroom', '/api/train/bedroom/apart', controller.bedroom.apart);

  // 班级表设置路由
  router.resources('class', '/api/train/class', controller.class); // index、create、show、destroy
  router.post('class', '/api/train/class/update/:id', controller.class.update);
  router.post('class', '/api/train/class/divide', controller.class.divide);

  // 部门表设置路由
  router.resources('department', '/api/train/department', controller.department); // index、create、show、destroy
  router.post('department', '/api/train/department/update/:id', controller.department.update);

  // 位置表设置路由
  router.resources('location', '/api/train/location', controller.location); // index、create、show、destroy
  router.post('location', '/api/train/location/update/:id', controller.location.update);

  // 培训计划表设置路由
  router.resources('trainplan', '/api/train/trainplan', controller.trainplan); // index、create、show、destroy
  router.post('trainplan', '/api/train/trainplan/update/:id', controller.trainplan.update);

  // 节假日表设置路由
  router.resources('festival', '/api/train/festival', controller.festival); // index、create、show、destroy
  router.post('festival', '/api/train/festival/update/:id', controller.festival.update);

  // 课程表设置路由
  router.resources('lesson', '/api/train/lesson', controller.lesson); // index、create、show、destroy
  router.post('lesson', '/api/train/lesson/update/:id', controller.lesson.update);

  // 培训计划学校上报时间表设置路由
  router.resources('schtime', '/api/train/schtime', controller.schtime); // index、create、show、destroy
  router.post('schtime', '/api/train/schtime/update/:id', controller.schtime.update);

  // 班主任全年计划表设置路由
  router.resources('teaplan', '/api/train/teaplan', controller.teaplan); // index、create、show、destroy
  router.post('teaplan', '/api/train/teaplan/update/:id', controller.teaplan.update);

  // 教师申请讲课表设置路由
  router.resources('apply', '/api/train/apply', controller.apply); // index、create、show、destroy
  router.post('apply', '/api/train/apply/update/:id', controller.apply.update);

  // 请假表设置路由
  router.resources('leave', '/api/train/leave', controller.leave); // index、create、show、destroy
  router.post('leave', '/api/train/leave/update/:id', controller.leave.update);

  // 分组表设置路由
  router.resources('group', '/api/train/group', controller.group); // index、create、show、destroy
  router.post('group', '/api/train/group/update/:id', controller.group.update);
  router.post('group', '/api/train/group/insert', controller.group.insert);
  router.post('group', '/api/train/group/exit', controller.group.exit);

  // 职责说明表设置路由
  router.resources('duty', '/api/train/duty', controller.duty); // index、create、show、destroy
  router.post('duty', '/api/train/duty/update/:id', controller.duty.update);

  // 学生上传作业表设置路由
  router.resources('uploadtask', '/api/train/uploadtask', controller.uploadtask); // index、create、show、destroy
  router.post('uploadtask', '/api/train/uploadtask/update/:id', controller.uploadtask.update);

  // 考勤表设置路由
  router.resources('attendance', '/api/train/attendance', controller.attendance); // index、create、show、destroy
  router.post('attendance', '/api/train/attendance/update/:id', controller.attendance.update);

  // 学校上传学生名单
  router.resources('school', '/api/train/school', controller.school); // index、create、show、destroy
  router.post('school', '/api/train/school/update/:id', controller.school.update);
  router.post('/api/train/school/import', controller.school.stuimport); // 名单上传

  // 民族表设置路由
  router.resources('nation', '/api/train/nation', controller.nation); // index、create、show、destroy
  router.post('nation', '/api/train/nation/update/:id', controller.nation.update);

  // 行政区划表设置路由
  router.resources('region', '/api/train/region', controller.region); // index、create、show、destroy
  router.post('region', '/api/train/region/update/:id', controller.region.update);

  // 用户表设置路由
  router.resources('user', '/api/train/user', controller.user); // index、create、show、destroy
  router.post('user', '/api/train/user/update/:id', controller.user.update);
  router.post('user', '/api/train/user/register', controller.user.register);// 学校注册
  router.post('user', '/api/train/user/bind', controller.user.bind);// 学生或班主任微信绑定
};
