'use strict';


const assert = require('assert');
const _ = require('lodash');
const { ObjectId } = require('mongoose').Types;
const { CrudService } = require('naf-framework-mongoose/lib/service');
const { BusinessError, ErrorCode } = require('naf-core').Error;

class UserService extends CrudService {
  constructor(ctx) {
    super(ctx, 'user');
    this.model = this.ctx.model.User;
    this.stuModel = this.ctx.model.Student;
    this.tModel = this.ctx.model.Teacher;
    this.schModel = this.ctx.model.School;
    this.hModel = this.ctx.model.Headteacher;
  }

  // 重写创建方法
  async create(data) {
    const { name, mobile, passwd, type, gender } = data;
    assert(name && mobile && passwd && type, '缺少部分信息项');
    assert(/^\d{11}$/i.test(mobile), 'mobile无效');
    const newdata = data;
    newdata.passwd = { secret: passwd };
    const res = await this.model.create(newdata);
    if (res) {
      // 如果是班主任的时候将用户信息填入班主任表
      if (type === '1') {
        const headt = { name, phone: mobile, gender };
        await this.hModel.create(headt);
      }
    }
    return res;
  }

  // 学校注册
  async register(data) {
    const { code, mobile, passwd, name } = data;
    assert(code && mobile && name && passwd, '缺少部分信息项');
    const user = await this.model.findOne({ mobile });
    if (user) {
      throw new BusinessError(ErrorCode.DATA_EXISTED);
    }
    const sch = await this.schModel.findOne({ code });
    if (!sch) {
      throw new BusinessError(ErrorCode.DATA_NOT_EXIST);
    }
    const newdata = { name, mobile, type: '2', uid: sch.id };
    newdata.passwd = { secret: passwd };
    const res = await this.model.create(newdata);
    return res;
  }

  // 学生绑定
  async bind(data) {
    const { openid, id_number, mobile, passwd } = data;
    assert(openid && id_number && mobile, '缺少部分信息项');
    let user = await this.model.findOne({ mobile });
    if (user) {
      if (user.passwd.secret !== passwd) {
        throw new BusinessError(ErrorCode.BAD_PASSWORD);
      }
      user.openid = openid;
      await user.save();
    } else {
      const stud = await this.stuModel.findOne({ id_number });
      if (!stud) {
        throw new BusinessError(ErrorCode.USER_NOT_EXIST);
      }
      stud.openid = openid;
      await stud.save();
      const newdata = { name: stud.name, mobile: stud.phone, type: '4', uid: stud.id, openid };
      newdata.passwd = { secret: '12345678' };
      user = await this.model.create(newdata);
    }
    return user;
  }

  // 通过openid查询用户信息
  async findByOpenid(openid) {
    // 通过openid查询用户信息
    const user = await this.model.findOne({ openid });
    return user;
  }

}

module.exports = UserService;
